<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
			<source>Authentication is required to read disk information</source>
			<translation>ディスク情報の読み取りには認証が必要です</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
			<source>Run Disk Manager Need Authentication</source>
			<translation>ディスク マネージャーの実行には認証が必要です</translation>
		</message>
	</context>
</TS>